@@ -11,10 +11,10 @@ from .list_model_admin import (
 )
 from .medication_admin import MedicationAdmin
 from .medication_lot_admin import MedicationLotAdmin
-from .medication_product_admin import MedicationProductAdmin
-from .medication_stock_admin import MedicationStockAdmin
-from .medication_stock_create_labels_admin import MedicationStockCreateLabelsAdmin
-from .medication_stock_receiving_admin import MedicationStockReceivingAdmin
+from .product_admin import ProductAdmin
 from .return_history_admin import ReturnHistoryAdmin
 from .rx_admin import RxAdmin
 from .rx_refill_admin import RxRefillAdmin
+from .stock_admin import StockAdmin
+from .stock_create_labels_admin import StockCreateLabelsAdmin
+from .stock_receiving_admin import StockReceivingAdmin
