@@ -5,6 +5,7 @@ class DispenseError(Exception):
     pass
 
 
+# TODO: dispense against stock for site / central, etc
 class Dispensing:
     def __init__(
         self,
@@ -12,25 +13,26 @@ class Dispensing:
         dispensed=None,
         exclude_id=None,
     ):
+        """Dispense against an existing refill with remaining items"""
         self.exclude_id = exclude_id
         self.rx_refill = rx_refill
         self.dispensed = dispensed
 
-    def check(self):
-        if self.remaining < float(self.dispensed):
-            raise DispenseError(
-                "Attempt to dispense more than remaining on prescription. "
-                f"Remaining={self.remaining}. Got {self.dispensed}."
-            )
-
     @property
     def remaining(self) -> float:
+        value = 0.0
         if self.rx_refill.total:
-            return float(self.rx_refill.total) - float(self.total_dispensed)
-        return 0.0
+            value = float(self.rx_refill.total) - float(self.total_dispensed)
+        if value < 0.0:
+            raise DispenseError(
+                "Attempt to dispense more than remaining on refill. "
+                f"Remaining={value}. Got {self.dispensed}."
+            )
+        return value
 
     @property
     def total_dispensed(self) -> float:
+        """Returns the total dispensed for this refill"""
         options = {}
         if self.rx_refill.total:
             if self.exclude_id:
