@@ -5,18 +5,18 @@ from .list_models import Container, FormulationType, FrequencyUnits, Route, Unit
 from .medication import Medication
 from .medication_lot import MedicationLot
 from .medication_order import MedicationOrder
-from .medication_product import MedicationProduct
-from .medication_stock import MedicationStock
-from .medication_stock_create_labels import Labels, MedicationStockCreateLabels
-from .medication_stock_receiving import MedicationStockReceiving
 from .model_mixins import (
     MedicationOrderModelMixin,
     StudyMedicationCrfModelMixin,
     StudyMedicationRefillModelMixin,
 )
+from .product import Product
 from .proxy_models import VisitSchedule
 from .return_history import ReturnError, ReturnHistory
 from .rx import Rx
 from .rx_refill import RxRefill
 from .signals import dispensing_history_on_post_save
+from .stock import Stock
+from .stock_create_labels import Labels, StockCreateLabels
+from .stock_receiving import StockReceiving
 from .subject import Subject
